@@ -163,7 +163,8 @@ static const AtkRoleItem role_items [] =
   { ATK_ROLE_HEADING, N_("heading")},
   { ATK_ROLE_PAGE, N_("page")},
   { ATK_ROLE_SECTION, N_("section")},
-  { ATK_ROLE_REDUNDANT_OBJECT, N_("redundant object")}
+  { ATK_ROLE_REDUNDANT_OBJECT, N_("redundant object")},
+  { ATK_ROLE_FORM, N_("form")}
 };
 
 static void            atk_object_class_init        (AtkObjectClass  *klass);
@@ -234,11 +235,22 @@ static const gchar* const atk_object_name_property_hypertext_num_links = "access
 
 #ifdef G_OS_WIN32
 
-#undef ATK_LOCALEDIR
+static HMODULE atk_dll;
 
-#define ATK_LOCALEDIR get_atk_locale_dir()
+BOOL WINAPI
+DllMain (HINSTANCE hinstDLL,
+	 DWORD     fdwReason,
+	 LPVOID    lpvReserved)
+{
+  switch (fdwReason)
+    {
+    case DLL_PROCESS_ATTACH:
+      atk_dll = (HMODULE) hinstDLL;
+      break;
+    }
 
-G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
+  return TRUE;
+}
 
 static const char *
 get_atk_locale_dir (void)
@@ -247,16 +259,35 @@ get_atk_locale_dir (void)
 
   if (!atk_localedir)
     {
-      gchar *temp;
+      const gchar *p;
+      gchar *root, *temp;
+      
+      /* ATK_LOCALEDIR might end in either /lib/locale or
+       * /share/locale. Scan for that slash.
+       */
+      p = ATK_LOCALEDIR + strlen (ATK_LOCALEDIR);
+      while (*--p != '/')
+	;
+      while (*--p != '/')
+	;
 
-      temp = g_win32_get_package_installation_subdirectory
-        (GETTEXT_PACKAGE, dll_name, "lib\\locale");
+      root = g_win32_get_package_installation_directory_of_module (atk_dll);
+      temp = g_build_filename (root, p, NULL);
+      g_free (root);
+
+      /* atk_localedir is passed to bindtextdomain() which isn't
+       * UTF-8-aware.
+       */
       atk_localedir = g_win32_locale_filename_from_utf8 (temp);
       g_free (temp);
     }
   return atk_localedir;
 }
 
+#undef ATK_LOCALEDIR
+
+#define ATK_LOCALEDIR get_atk_locale_dir()
+
 #endif
 
 static void
@@ -737,7 +768,7 @@ atk_object_get_role (AtkObject *accessible)
  *
  * Gets the layer of the accessible.
  *
- * @Deprecated: Use atk_component_get_layer instead.
+ * Deprecated: Use atk_component_get_layer instead.
  *
  * Returns: an #AtkLayer which is the layer of the accessible
  **/
@@ -762,7 +793,7 @@ atk_object_get_layer (AtkObject *accessible)
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
  *
- * @Deprecated: Use atk_component_get_mdi_zorder instead.
+ * Deprecated: Use atk_component_get_mdi_zorder instead.
  *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
@@ -992,6 +1023,8 @@ atk_object_notify_state_change (AtkObject *accessible,
 {
   G_CONST_RETURN gchar* name;
 
+  g_return_if_fail (ATK_IS_OBJECT (accessible));
+
   name = atk_state_type_get_name (state);
   g_signal_emit (accessible, atk_object_signals[STATE_CHANGE],
                  g_quark_from_string (name),
@@ -1036,7 +1069,7 @@ atk_implementor_ref_accessible (AtkImplementor *implementor)
  * as distinct from strongly-typed object data available via other get/set methods.
  * Not all objects have explicit "name-value pair" #AtkAttributeSet properties.
  *
- * @Since ATK 1.12
+ * Since: ATK 1.12
  *
  * Returns: an #AtkAttributeSet consisting of all explicit properties/annotations applied to 
  * the object, or an empty set if the object has no name-value pair attributes assigned to it.
